@@ -1,5 +1,7 @@
 from django.utils.module_loading import import_string
 
+from rest_framework.settings import api_settings
+
 from likes.settings import LIKES_REST_PAGINATION_CLASS
 
 __all__ = (
@@ -17,3 +19,5 @@ def get_pagination_class():
             return import_string(pagination_class)
         except ImportError:
             pass
+
+    return api_settings.DEFAULT_PAGINATION_CLASS
